# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.configuration import Server
from coingeckoapiv3.controllers.base_controller import BaseController


class TrendingController(BaseController):

    """A Controller to access Endpoints in the coingeckoapiv3 API."""

    def __init__(self, config, call_back=None):
        super(TrendingController, self).__init__(config, call_back)

    def gettrendingsearchcoins_top_7_on_coin_geckointhelast_24_hours(self):
        """Does a GET request to /search/trending.

        Top-7 trending coins on CoinGecko as searched by users in the last 24
        hours (Ordered by most popular first)

        Returns:
            void: Response from the API. List trending coins by most popular
                first

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/search/trending'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
coingeckoapiv3

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from coingeckoapiv3.api_helper import APIHelper
from coingeckoapiv3.controllers.exchange_rates_controller import ExchangeRatesController


class ExchangeRatesControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(ExchangeRatesControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = ExchangeRatesController(cls.config, cls.response_catcher)

    # Get BTC-to-Currency exchange rates
    #
    def test_get_btc_to_currencyexchangerates(self):

        # Perform the API call through the SDK function
        self.controller.get_btc_to_currencyexchangerates()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

